@@ -52,45 +52,49 @@
 
 
 /* Color defines */
-#define COLOR_BLACK  0x00
-#define COLOR_WHITE  0x01
+#define COLOR_BLACK     0x00
+#define COLOR_WHITE     0x01
 
 /* TGI color defines */
-#define TGI_COLOR_BLACK      0x00
-#define TGI_COLOR_GREEN      0x01
-#define TGI_COLOR_VIOLET     0x02
-#define TGI_COLOR_WHITE      0x03
-#define TGI_COLOR_BLACK2     0x04
-#define TGI_COLOR_ORANGE     0x05
-#define TGI_COLOR_BLUE       0x06
-#define TGI_COLOR_WHITE2     0x07
+#define TGI_COLOR_BLACK         0x00
+#define TGI_COLOR_GREEN         0x01
+#define TGI_COLOR_VIOLET        0x02
+#define TGI_COLOR_WHITE         0x03
+#define TGI_COLOR_BLACK2        0x04
+#define TGI_COLOR_ORANGE        0x05
+#define TGI_COLOR_BLUE          0x06
+#define TGI_COLOR_WHITE2        0x07
 
-#define TGI_COLOR_MAGENTA    TGI_COLOR_BLACK2
-#define TGI_COLOR_DARKBLUE   TGI_COLOR_WHITE2
-#define TGI_COLOR_DARKGREEN  0x08
-#define TGI_COLOR_GRAY       0x09
-#define TGI_COLOR_CYAN       0x0A
-#define TGI_COLOR_BROWN      0x0B
-#define TGI_COLOR_GRAY2      0x0C
-#define TGI_COLOR_PINK       0x0D
-#define TGI_COLOR_YELLOW     0x0E
-#define TGI_COLOR_AQUA       0x0F
+#define TGI_COLOR_MAGENTA       TGI_COLOR_BLACK2
+#define TGI_COLOR_DARKBLUE      TGI_COLOR_WHITE2
+#define TGI_COLOR_DARKGREEN     0x08
+#define TGI_COLOR_GRAY          0x09
+#define TGI_COLOR_CYAN          0x0A
+#define TGI_COLOR_BROWN         0x0B
+#define TGI_COLOR_GRAY2         0x0C
+#define TGI_COLOR_PINK          0x0D
+#define TGI_COLOR_YELLOW        0x0E
+#define TGI_COLOR_AQUA          0x0F
 
 /* Characters codes */
-#define CH_ENTER       0x0D
-#define CH_ESC         0x1B
-#define CH_CURS_LEFT   0x08
-#define CH_CURS_RIGHT  0x15
+#define CH_ENTER        0x0D
+#define CH_ESC          0x1B
+#define CH_CURS_LEFT    0x08
+#define CH_CURS_RIGHT   0x15
 
-#define CH_ULCORNER  '+'
-#define CH_URCORNER  '+'
-#define CH_LLCORNER  '+'
-#define CH_LRCORNER  '+'
-#define CH_TTEE      '+'
-#define CH_BTEE      '+'
-#define CH_LTEE      '+'
-#define CH_RTEE      '+'
-#define CH_CROSS     '+'
+#if !defined(__APPLE2ENH__)
+#define CH_HLINE        '-'
+#define CH_VLINE        '!'
+#define CH_ULCORNER     '+'
+#define CH_URCORNER     '+'
+#define CH_LLCORNER     '+'
+#define CH_LRCORNER     '+'
+#define CH_TTEE         '+'
+#define CH_BTEE         '+'
+#define CH_LTEE         '+'
+#define CH_RTEE         '+'
+#define CH_CROSS        '+'
+#endif
 
 /* Masks for joy_read */
 #define JOY_UP_MASK     0x10
@@ -101,21 +105,21 @@
 #define JOY_BTN_2_MASK  0x80
 
 /* Return codes for get_ostype */
-#define APPLE_UNKNOWN  0x00
-#define APPLE_II       0x10  /* Apple ][                    */
-#define APPLE_IIPLUS   0x11  /* Apple ][+                   */
-#define APPLE_IIIEM    0x20  /* Apple /// (emulation)       */
-#define APPLE_IIE      0x30  /* Apple //e                   */
-#define APPLE_IIEENH   0x31  /* Apple //e (enhanced)        */
-#define APPLE_IIECARD  0x40  /* Apple //e Option Card       */
-#define APPLE_IIC      0x50  /* Apple //c                   */
-#define APPLE_IIC35    0x51  /* Apple //c (3.5 ROM)         */
-#define APPLE_IICEXP   0x53  /* Apple //c (Mem. Exp.)       */
-#define APPLE_IICREV   0x54  /* Apple //c (Rev. Mem. Exp.)  */
-#define APPLE_IICPLUS  0x55  /* Apple //c Plus              */
-#define APPLE_IIGS     0x80  /* Apple IIgs                  */
-#define APPLE_IIGS1    0x81  /* Apple IIgs (ROM 1)          */
-#define APPLE_IIGS3    0x83  /* Apple IIgs (ROM 3)          */
+#define APPLE_UNKNOWN   0x00
+#define APPLE_II        0x10  /* Apple ][                    */
+#define APPLE_IIPLUS    0x11  /* Apple ][+                   */
+#define APPLE_IIIEM     0x20  /* Apple /// (emulation)       */
+#define APPLE_IIE       0x30  /* Apple //e                   */
+#define APPLE_IIEENH    0x31  /* Apple //e (enhanced)        */
+#define APPLE_IIECARD   0x40  /* Apple //e Option Card       */
+#define APPLE_IIC       0x50  /* Apple //c                   */
+#define APPLE_IIC35     0x51  /* Apple //c (3.5 ROM)         */
+#define APPLE_IICEXP    0x53  /* Apple //c (Mem. Exp.)       */
+#define APPLE_IICREV    0x54  /* Apple //c (Rev. Mem. Exp.)  */
+#define APPLE_IICPLUS   0x55  /* Apple //c Plus              */
+#define APPLE_IIGS      0x80  /* Apple IIgs                  */
+#define APPLE_IIGS1     0x81  /* Apple IIgs (ROM 1)          */
+#define APPLE_IIGS3     0x83  /* Apple IIgs (ROM 3)          */
 
 extern unsigned char _dos_type;
 /* Valid _dos_type values:
@@ -200,9 +204,9 @@ void rebootafterexit (void);
 ** to be overlaid by macros with the same names, saving the function call
 ** overhead.
 */
-#define _textcolor(color)    COLOR_WHITE
-#define _bgcolor(color)      COLOR_BLACK
-#define _bordercolor(color)  COLOR_BLACK
+#define _textcolor(color)       COLOR_WHITE
+#define _bgcolor(color)         COLOR_BLACK
+#define _bordercolor(color)     COLOR_BLACK
 
 
 
