@@ -38,6 +38,17 @@
 
 
 
+/*****************************************************************************/
+/*                                   Data                                    */
+/*****************************************************************************/
+
+
+
+#define PARAVIRT_BASE        0xFFF4
+/* Lowest address used by a paravirtualization hook */
+
+
+
 /*****************************************************************************/
 /*                                   Code                                    */
 /*****************************************************************************/
