@@ -32,7 +32,7 @@ int main(void)
         fs=(func((fd/a),(func(2,0x0082c90f))));
 }
 
-i get "Error: `)' expected" on that line. (this is with the snapshot, freshly 
+i get "Error: ')' expected" on that line. (this is with the snapshot, freshly 
 compiled 5 minutes ago)
 */
 
