@@ -7,13 +7,13 @@
 
 static unsigned char flag;
 
-static void trampoline_set() {
+static void trampoline_set(void) {
         asm("ldy tmp4");
         asm("sty %v", flag);
         asm("jsr callptr4");
 }
 
-void trampoline_inc() {
+void trampoline_inc(void) {
         asm("inc %v", flag);
         asm("jsr callptr4");
 }
@@ -35,7 +35,7 @@ void func1(void);
 #pragma wrapped-call(pop)
 #pragma wrapped-call(pop)
 
-void func1() {
+void func1(void) {
         func2();
 }
 
